@@ -3,7 +3,7 @@ from shexer.utils.target_elements import tune_target_classes_if_needed
 from shexer.utils.dict import reverse_keys_and_values
 
 
-def get_class_shexer(class_instances_target_dict,
+def get_class_shexer(class_counts,
                      class_profile_dict,
                      remove_empty_shapes,
                      original_target_classes,
@@ -18,13 +18,10 @@ def get_class_shexer(class_instances_target_dict,
                      allow_opt_cardinality,
                      disable_exact_cardinality,
                      shapes_namespace):
-    class_count_dicts = {}
 
-    for a_class_key in class_instances_target_dict:
-        class_count_dicts[a_class_key] = len(class_instances_target_dict[a_class_key])
 
     return ClassShexer(
-        class_counts_dict=class_count_dicts,
+        class_counts_dict=class_counts,
         class_profile_dict=class_profile_dict,
         class_profile_json_file=None,
         remove_empty_shapes=remove_empty_shapes,
